@@ -15,9 +15,10 @@ COMPLETION_FOR_SUPPORTED_SHELLS_TESTS = (
         """\
 _pip_completion()
 {
+    local IFS=$' \\t\\n'
     COMPREPLY=( $( COMP_WORDS="${COMP_WORDS[*]}" \\
                    COMP_CWORD=$COMP_CWORD \\
-                   PIP_AUTO_COMPLETE=1 $1 2>/dev/null ) )
+                   PIP_AUTO_COMPLETE=1 "$1" 2>/dev/null ) )
 }
 complete -o default -F _pip_completion pip""",
     ),
@@ -94,7 +95,7 @@ def script_with_launchers(
     tmpdir = tmpdir_factory.mktemp("script_with_launchers")
     script = script_factory(tmpdir.joinpath("workspace"))
     # Re-install pip so we get the launchers.
-    script.pip_install_local("-f", common_wheels, pip_src)
+    script.pip("install", "--no-index", "-f", common_wheels, pip_src)
     return script
 
 
