@@ -70,38 +70,32 @@ def arg_recording_sdist_maker(
     return _arg_recording_sdist_maker
 
 
-@pytest.mark.network
-def test_requirements_file(script: PipTestEnvironment) -> None:
+def test_requirements_file(script: PipTestEnvironment, data: TestData) -> None:
     """
     Test installing from a requirements file.
 
     """
-    other_lib_name, other_lib_version = "peppercorn", "0.6"
-    script.scratch_path.joinpath("initools-req.txt").write_text(
-        textwrap.dedent(
-            f"""\
+    file = script.temporary_multiline_file(
+        "initools-req.txt",
+        """\
         INITools==0.2
         # and something else to test out:
-        {other_lib_name}<={other_lib_version}
-        """
-        )
+        six>=1.0.0
+        """,
     )
-    result = script.pip("install", "-r", script.scratch_path / "initools-req.txt")
-    result.did_create(script.site_packages / "initools-0.2.dist-info")
-    result.did_create(script.site_packages / "initools")
-    assert result.files_created[script.site_packages / other_lib_name].dir
-    fn = f"{other_lib_name}-{other_lib_version}.dist-info"
-    assert result.files_created[script.site_packages / fn].dir
+    script.pip_install_local(
+        "-r", file, find_links=[data.pypi_packages, data.common_wheels]
+    )
+    script.assert_installed(initools="0.2", six="1.17.0")
 
 
-@pytest.mark.network
 @pytest.mark.parametrize(
     "path, groupname",
     [
-        (None, "initools"),
-        ("pyproject.toml", "initools"),
-        ("./pyproject.toml", "initools"),
-        (lambda path: path.absolute(), "initools"),
+        (None, "reqs"),
+        ("pyproject.toml", "reqs"),
+        ("./pyproject.toml", "reqs"),
+        (lambda path: path.absolute(), "reqs"),
     ],
 )
 def test_dependency_group(
@@ -112,17 +106,15 @@ def test_dependency_group(
     """
     Test installing from a dependency group.
     """
-    pyproject = script.scratch_path / "pyproject.toml"
-    pyproject.write_text(
-        textwrap.dedent(
-            """\
+    pyproject = script.temporary_multiline_file(
+        "pyproject.toml",
+        """\
             [dependency-groups]
-            initools = [
-                "INITools==0.2",
-                "peppercorn<=0.6",
+            reqs = [
+                "simple.dist==0.1",
+                "simplewheel<2",
             ]
-            """
-        )
+            """,
     )
     if path is None:
         arg = groupname
@@ -130,55 +122,40 @@ def test_dependency_group(
         if callable(path):
             path = path(pyproject)
         arg = f"{path}:{groupname}"
-    result = script.pip("install", "--group", arg)
-    result.did_create(script.site_packages / "initools-0.2.dist-info")
-    result.did_create(script.site_packages / "initools")
-    assert result.files_created[script.site_packages / "peppercorn"].dir
-    assert result.files_created[script.site_packages / "peppercorn-0.6.dist-info"].dir
+    script.pip_install_local("--group", arg)
+    script.assert_installed(**{"simple.dist": "0.1", "simplewheel": "1.0"})
 
 
-@pytest.mark.network
 def test_multiple_dependency_groups(script: PipTestEnvironment) -> None:
     """
     Test installing from two dependency groups simultaneously.
-
     """
-    pyproject = script.scratch_path / "pyproject.toml"
-    pyproject.write_text(
-        textwrap.dedent(
-            """\
+    script.temporary_multiline_file(
+        "pyproject.toml",
+        """\
             [dependency-groups]
-            initools = ["INITools==0.2"]
-            peppercorn = ["peppercorn<=0.6"]
-            """
-        )
+            simple = ["simple.dist==0.1"]
+            othersimple = ["simplewheel<2"]
+            """,
     )
-    result = script.pip("install", "--group", "initools", "--group", "peppercorn")
-    result.did_create(script.site_packages / "initools-0.2.dist-info")
-    result.did_create(script.site_packages / "initools")
-    assert result.files_created[script.site_packages / "peppercorn"].dir
-    assert result.files_created[script.site_packages / "peppercorn-0.6.dist-info"].dir
+    script.pip_install_local("--group", "simple", "--group", "othersimple")
+    script.assert_installed(**{"simple.dist": "0.1", "simplewheel": "1.0"})
 
 
-@pytest.mark.network
 def test_dependency_group_with_non_normalized_name(script: PipTestEnvironment) -> None:
     """
     Test installing from a dependency group with a non-normalized name, verifying that
     the pyproject.toml content and CLI arg are normalized to match.
-
     """
-    pyproject = script.scratch_path / "pyproject.toml"
-    pyproject.write_text(
-        textwrap.dedent(
-            """\
+    script.temporary_multiline_file(
+        "pyproject.toml",
+        """\
             [dependency-groups]
-            INITOOLS = ["INITools==0.2"]
-            """
-        )
+            INITOOLS = ["simplewheel==1.0"]
+            """,
     )
-    result = script.pip("install", "--group", "IniTools")
-    result.did_create(script.site_packages / "initools-0.2.dist-info")
-    result.did_create(script.site_packages / "initools")
+    script.pip_install_local("--group", "IniTools")
+    script.assert_installed(simplewheel="1.0")
 
 
 def test_schema_check_in_requirements_file(script: PipTestEnvironment) -> None:
@@ -531,7 +508,7 @@ def test_constraints_local_editable_install_pep518(
 ) -> None:
     to_install = data.src.joinpath("pep518-3.0")
 
-    script.pip("download", "setuptools", "wheel", "-d", data.packages)
+    script.pip("download", "setuptools", "-d", data.packages)
     script.pip("install", "--no-index", "-f", data.find_links, "-e", to_install)
 
 
@@ -669,12 +646,12 @@ def test_install_with_extras_from_constraints(
     script: PipTestEnvironment, data: TestData, resolver_variant: ResolverVariant
 ) -> None:
     to_install = data.packages.joinpath("LocalExtras")
-    script.scratch_path.joinpath("constraints.txt").write_text(
-        f"{to_install.as_uri()}#egg=LocalExtras[bar]"
+    file = script.temporary_file(
+        "constraints.txt", f"LocalExtras[bar] @ {to_install.as_uri()}"
     )
     result = script.pip_install_local(
         "-c",
-        script.scratch_path / "constraints.txt",
+        file,
         "LocalExtras",
         allow_stderr_warning=True,
         expect_error=(resolver_variant == "resolvelib"),
@@ -707,12 +684,12 @@ def test_install_with_extras_joined(
     script: PipTestEnvironment, data: TestData, resolver_variant: ResolverVariant
 ) -> None:
     to_install = data.packages.joinpath("LocalExtras")
-    script.scratch_path.joinpath("constraints.txt").write_text(
-        f"{to_install.as_uri()}#egg=LocalExtras[bar]"
+    file = script.temporary_file(
+        "constraints.txt", f"LocalExtras[bar] @ {to_install.as_uri()}"
     )
     result = script.pip_install_local(
         "-c",
-        script.scratch_path / "constraints.txt",
+        file,
         "LocalExtras[baz]",
         allow_stderr_warning=True,
         expect_error=(resolver_variant == "resolvelib"),
@@ -728,12 +705,12 @@ def test_install_with_extras_editable_joined(
     script: PipTestEnvironment, data: TestData, resolver_variant: ResolverVariant
 ) -> None:
     to_install = data.packages.joinpath("LocalExtras")
-    script.scratch_path.joinpath("constraints.txt").write_text(
-        f"-e {to_install.as_uri()}#egg=LocalExtras[bar]"
+    file = script.temporary_file(
+        "constraints.txt", f"-e LocalExtras[bar] @ {to_install.as_uri()}"
     )
     result = script.pip_install_local(
         "-c",
-        script.scratch_path / "constraints.txt",
+        file,
         "LocalExtras[baz]",
         allow_stderr_warning=True,
         expect_error=(resolver_variant == "resolvelib"),
@@ -918,15 +895,11 @@ def test_config_settings_local_to_package(
         )
     )
 
-    script.pip(
-        "install",
-        "--no-index",
-        "-f",
-        script.scratch_path,
-        "-f",
-        common_wheels,
+    script.pip_install_local(
+        "--no-build-isolation",
         "-r",
         reqs_file,
+        find_links=[script.scratch_path, common_wheels],
     )
 
     simple0_args = simple0_sdist.args()
